"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLastPathname = exports.removeQueryString = exports.getDomain = exports.hasValidUrlProtocol = exports.isUrl = void 0;
var isUrl = function (str) {
    return /^(ftp|http|https):\/\/[^ "]+$/.test(str);
};
exports.isUrl = isUrl;
var hasValidUrlProtocol = function (url) {
    return ["http://", "https://", "ftp://"].some(function (protocol) { return url.indexOf(protocol) >= 0; });
};
exports.hasValidUrlProtocol = hasValidUrlProtocol;
var getDomain = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    var result;
    var match = url.match(/^(?:(https|ftp|http)?:\/\/)?(?:[^@\n]+@)?(?:www\.)?([^:\/\n\?\=]+)/im);
    if (match) {
        result = match[2];
        match = result.match(/^[^\.]+\.(.+\..+)$/);
        if (match) {
            result = match[1];
        }
    }
    return result;
};
exports.getDomain = getDomain;
var removeQueryString = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    return url.replace(/(\?.*)|(#.*)/g, "");
};
exports.removeQueryString = removeQueryString;
var getLastPathname = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    var noQueryString = url.replace(/(\?.*)|(#.*)/g, "");
    if (!noQueryString)
        return "";
    return noQueryString.split("/").filter(function (item) { return item != ""; }).pop();
};
exports.getLastPathname = getLastPathname;
