"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isImageUrl = exports.getQueryString = exports.getLastPathname = exports.removeQueryString = exports.getDomain = exports.hasValidUrlProtocol = exports.isUrl = void 0;
var isUrl = function (str) {
    return /^(ftp|http|https):\/\/[^ "]+$/.test(str);
};
exports.isUrl = isUrl;
var hasValidUrlProtocol = function (url) {
    return ["http://", "https://", "ftp://"].some(function (protocol) { return url.indexOf(protocol) >= 0; });
};
exports.hasValidUrlProtocol = hasValidUrlProtocol;
var getDomain = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    var result;
    var match = url.match(/^(?:(https|ftp|http)?:\/\/)?(?:[^@\n]+@)?(?:www\.)?([^:\/\n\?\=]+)/im);
    if (match) {
        result = match[2];
        match = result.match(/^[^\.]+\.(.+\..+)$/);
        if (match) {
            result = match[1];
        }
    }
    return result;
};
exports.getDomain = getDomain;
var removeQueryString = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    return url.replace(/(\?.*)|(#.*)/g, "");
};
exports.removeQueryString = removeQueryString;
var getLastPathname = function (url) {
    if (!isUrl(url))
        throw new Error("Parameter is not a valid url!");
    var noQueryString = url.replace(/(\?.*)|(#.*)/g, "");
    if (!noQueryString)
        return "";
    return noQueryString
        .split("/")
        .filter(function (item) { return item !== ""; })
        .pop();
};
exports.getLastPathname = getLastPathname;
var getQueryString = function (url) {
    var _a, _b;
    if (!isUrl(url) || !url)
        throw new Error("Parameter is not a valid url!");
    return (((_b = (_a = url === null || url === void 0 ? void 0 : url.split("?")) === null || _a === void 0 ? void 0 : _a[1]) === null || _b === void 0 ? void 0 : _b.split("&")) || []).reduce(function (prev, curr) {
        var keyVal = curr.split("=");
        var key = keyVal[0];
        var val = keyVal[1];
        prev[key] = val;
        return prev;
    }, {});
};
exports.getQueryString = getQueryString;
var isImageUrl = function (url) {
    if (!isUrl(url) || !url)
        throw new Error("Parameter is not a valid url!");
    return (url.match(/^http[^\?]*.(jpg|jpeg|gif|png|tiff|bmp)(\?(.*))?$/gim) != null);
};
exports.isImageUrl = isImageUrl;
